class URL(object):
    SANDBOX_URL = 'https://uatcheckout.thawani.om/api/v1'
    SANDBOX_ENDPOINT = 'https://uatcheckout.thawani.om'
    PROD_ENDPOINT = 'https://checkout.thawani.om'
    PROD_URL = 'https://checkout.thawani.om/api/v1'




    ORDER_URL = "/orders"
    PAYMENT_INTENT   ="/payment_intents"
    INVOICE_URL = "/invoices"
    PAYMENT_LINK_URL = "/payment_links"
    PAYMENTS_URL = "/payments"
    REFUNDS_URL = "/refunds"
    CARD_URL = "/cards"
    CUSTOMER_URL = "/customers"
    TRANSFER_URL = "/transfers"
    VIRTUAL_ACCOUNT_URL = "/virtual_accounts"
    SUBSCRIPTION_URL = "/subscriptions"
    ADDON_URL = "/addons"
    PLAN_URL = "/plans"
    SETTLEMENT_URL = "/settlements"
    ITEM_URL = "/items"
    QRCODE_URL = "/payments/qr_codes"
    REGISTRATION_LINK_URL = "/subscription_registration"
    FUND_ACCOUNT_URL = "/fund_accounts"
    CHECKOUT_SESSION_URL="/checkout/session"
    PAYMENT_METHOD_URL="/payment_methods"
    PAYMENT_LINK="/pay"
    CHECKOUT_SESSION_BY_REFERENCE_ID="/checkout/reference"
    
